summaryrefslogtreecommitdiffstats
path: root/src/graphwidget.h
diff options
context:
space:
mode:
authorSlávek Banko <slavek.banko@axis.cz>2013-10-08 00:13:25 +0200
committerSlávek Banko <slavek.banko@axis.cz>2013-10-08 05:14:53 +0200
commit84f5a315c3429b47a7eff15e626e2efdbe4f6e5e (patch)
tree770861aa9033e1dc6c5168358194ff85b32dd429 /src/graphwidget.h
parent57d8bb3d12aed373eee08915f0ff19f5233aabe3 (diff)
downloadkscope-84f5a315c3429b47a7eff15e626e2efdbe4f6e5e.tar.gz
kscope-84f5a315c3429b47a7eff15e626e2efdbe4f6e5e.zip
Initial TQt conversion
Diffstat (limited to 'src/graphwidget.h')
-rw-r--r--src/graphwidget.h62
1 files changed, 31 insertions, 31 deletions
diff --git a/src/graphwidget.h b/src/graphwidget.h
index 119ddbb..55224c6 100644
--- a/src/graphwidget.h
+++ b/src/graphwidget.h
@@ -28,9 +28,9 @@
#ifndef GRAPHWIDGET_H
#define GRAPHWIDGET_H
-#include <qcanvas.h>
-#include <qpopupmenu.h>
-#include <qdict.h>
+#include <ntqcanvas.h>
+#include <ntqpopupmenu.h>
+#include <ntqdict.h>
#include "cscopefrontend.h"
#include "graphnode.h"
#include "dotfrontend.h"
@@ -39,7 +39,7 @@ class ProgressDlg;
/**
* A widget that displays call tree graphs generated by graphviz.
* This class is based on a QCanvasView widget, and displays two types of
* canvas items: GraphNode, which draws the name of a function inside a
* polygon, and ArrowEdge, which is a directed graph edge shaped like an
* arrow.
@@ -58,12 +58,12 @@ class ProgressDlg;
* any of these widgets.
* @author Elad Lahav
*/
-class GraphWidget : public QCanvasView
+class GraphWidget : public TQCanvasView
{
Q_OBJECT
public:
- GraphWidget(QWidget* pParent = 0, const char* szName = 0);
+ GraphWidget(TQWidget* pParent = 0, const char* szName = 0);
~GraphWidget();
/**
@@ -74,39 +74,39 @@ public:
struct CallData
{
/** The name of the calling function. */
- QString m_sCaller;
+ TQString m_sCaller;
/** The name of the called function. */
- QString m_sCallee;
+ TQString m_sCallee;
/** Path of the file in which the call appears. */
- QString m_sFile;
+ TQString m_sFile;
/** The line number of the call. */
- QString m_sLine;
+ TQString m_sLine;
/** The call's text. */
- QString m_sText;
+ TQString m_sText;
};
/** Graph orientation values. */
enum Orientation { Portrait, Landscape };
- void setRoot(const QString&);
- GraphNode* addNode(const QString&, bool bMultiCall = false);
+ void setRoot(const TQString&);
+ GraphNode* addNode(const TQString&, bool bMultiCall = false);
void addCall(const CallData&);
- void addMultiCall(const QString&, bool);
+ void addMultiCall(const TQString&, bool);
void draw();
void save(FILE*);
- void save(const QString&);
+ void save(const TQString&);
void zoom(bool);
void setZoom(double);
void rotate();
- QString getTip(const QPoint&, QRect&);
+ TQString getTip(const TQPoint&, TQRect&);
void resize(int, int);
- void drawNode(const QString&, const QRect&);
- void drawEdge(const QString&, const QString&, const QPointArray&);
+ void drawNode(const TQString&, const TQRect&);
+ void drawEdge(const TQString&, const TQString&, const TQPointArray&);
/**
* Adjusts the maximal number of calling/called functions shown for
@@ -127,16 +127,16 @@ signals:
* @param sPath The full path of the file to show
* @param nLine The line number in this file
*/
- void lineRequested(const QString& sPath, uint nLine);
+ void lineRequested(const TQString& sPath, uint nLine);
protected:
- virtual void drawContents(QPainter*, int, int, int, int);
- virtual void contentsMousePressEvent(QMouseEvent*);
+ virtual void drawContents(TQPainter*, int, int, int, int);
+ virtual void contentsMousePressEvent(TQMouseEvent*);
private:
/** The graph is stored as a map of nodes indexed by their names.
Each node holds a list of outgoing edges. */
- QDict<GraphNode> m_dictNodes;
+ TQDict<GraphNode> m_dictNodes;
/** A Cscope process to use for running queries. */
CscopeFrontend* m_pCscope;
@@ -149,23 +149,23 @@ private:
/** Remembers the function the was last queried for calling/called
functions. */
- QString m_sQueriedFunc;
+ TQString m_sQueriedFunc;
/** Remembers whether the last query was for calling or called
functions. */
bool m_bCalled;
/** The node over which the popup menu has been invoked. */
- QCanvasPolygonalItem* m_pMenuItem;
+ TQCanvasPolygonalItem* m_pMenuItem;
/** A popup menu that appears when a node is right-clicked. */
- QPopupMenu* m_pNodePopup;
+ TQPopupMenu* m_pNodePopup;
/** A popup menu that appears when a node is right-clicked. */
- QPopupMenu* m_pMultiCallPopup;
+ TQPopupMenu* m_pMultiCallPopup;
/** A popup menu that appears when an edge is right-clicked. */
- QPopupMenu* m_pEdgePopup;
+ TQPopupMenu* m_pEdgePopup;
/** The zoom factor for the graph. */
double m_dZoom;
@@ -181,16 +181,16 @@ private:
uint m_nMultiCallNum;
/** Holds the path of the temporary dot file used for drawing the graph. */
- QString m_sDrawFilePath;
+ TQString m_sDrawFilePath;
/** Allows lengthy drawing operations to be cancelled. */
ProgressDlg* m_pProgressDlg;
- void write(QTextStream&, const QString&, const QString&, bool);
+ void write(TQTextStream&, const TQString&, const TQString&, bool);
void removeEdges(GraphNode*, bool);
void removeDisconnected(GraphNode*);
- void showNodeMenu(GraphNode*, const QPoint&);
- void showEdgeMenu(GraphEdge*, const QPoint&);
+ void showNodeMenu(GraphNode*, const TQPoint&);
+ void showEdgeMenu(GraphEdge*, const TQPoint&);
private slots:
void slotDotFinished();
@@ -39,7 +39,7 @@ class ProgressDlg;
/**
* A widget that displays call tree graphs generated by graphviz.
- * This class is based on a QCanvasView widget, and displays two types of
+ * This class is based on a TQCanvasView widget, and displays two types of
* canvas items: GraphNode, which draws the name of a function inside a
* polygon, and ArrowEdge, which is a directed graph edge shaped like an